@@ -47,11 +47,14 @@ class JWS(PyJWS):
         except:
             host, version = None, 'v1'
         kid = header['kid']
-        env = host.split('.')[0][-4:]
-        if env in ['-stg', '-dev']:
-            host = 'https://auth-stg.revtel-api.com'
-        else:
-            host = 'https://auth.revtel-api.com'
+
+        if host:
+            env = host.split('.')[0][-4:]
+
+            elif env in ['-stg', '-dev']:
+                host = 'https://auth-stg.revtel-api.com'
+            else:
+                host = 'https://auth.revtel-api.com'
 
         if version == 'v3':
             url = f'{host}/{version}/certs'
